# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-22 06:45
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0038_auto_20180617_1423'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usercoursesection',
            name='updated_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
