# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-03-24 09:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0017_auto_20180324_0915'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userimage',
            name='image',
            field=models.ImageField(upload_to='course/%Y/%m/%d', verbose_name='\u56fe\u7247'),
        ),
    ]
