{% extends "bee_django_course/base.html" %}
{% block content %}
    <h4>视频详情</h4>
    <div class="video">
        <iframe src="{{ video_src }}" frameborder="0" width="100%" height="100%"></iframe>
    </div>
    <h4>说明：</h4>
    <div>
        {{ video.info | default:'' | linebreaks }}
    </div>
{% endblock %}