# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-03-30 00:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0021_auto_20180328_1554'),
    ]

    operations = [
        migrations.CreateModel(
            name='SectionVideo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('section', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.Section', verbose_name='\u5173\u8054\u7684\u8bfe\u4ef6')),
                ('video', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.Video', verbose_name='\u5173\u8054\u7684\u89c6\u9891')),
            ],
        ),
    ]
