# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-07-04 23:36
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0045_auto_20180626_1326'),
    ]

    operations = [
        migrations.AddField(
            model_name='section',
            name='type',
            field=models.IntegerField(default=0),
        ),
    ]
