{% extends "bee_django_course/base.html" %}

{% block content %}

    {% for e in current_course %}
        <div class="col-md-12 well">
            <a href="{% url 'bee_django_course:manage_user_course_section_list' user_course_id=e.id %}">
                <h4>{{ e.course.name }}</h4>
            </a>
        </div>
    {% endfor %}
    {% for e in finished_course %}
        <a href="{% url 'bee_django_course:manage_user_course_section_list' user_course_id=e.id %}">
            <h4>{{ e.course.name }}</h4>
        </a>
    {% endfor %}

{% endblock content %}