<div class="notes">
    {% for n in notes %}
        <div class="note" style="margin-top:5px; padding:5px; border-bottom:1px solid #ddd;">
            <div class="note_user" style="color: #8c8c8c;">{{ n.user.first_name | default:n.user.username }}</div>
            <div class="note_note" style="margin-top:5px;">{{ n.note | safe }}</div>
            <div class="note_date" style="text-align: right;color: #8c8c8c;">{{ n.created_at }}</div>
        </div>
    {% endfor %}
</div>
