# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-03-24 01:15
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0016_course_teacher'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usercourse',
            name='course',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.Course', verbose_name='\u8bfe\u7a0b'),
        ),
    ]
